@@ -1,8 +1,12 @@
+import base64
 import copy
 import json
-from dataclasses import fields, is_dataclass
+from abc import ABC, abstractmethod
+from dataclasses import asdict, fields, is_dataclass
+from datetime import date, datetime, time
 from enum import Enum
 from typing import Any, List, Tuple
+from uuid import UUID
 
 import yaml
 from essentials.json import FriendlyEncoder
@@ -13,10 +17,46 @@ class Format(Enum):
     JSON = "JSON"
 
 
-class OpenAPIRoot:
+class OpenAPIElement:
+    """Base class for all OpenAPI Elements"""
+
+
+class OpenAPIRoot(OpenAPIElement):
     """Base class for a root OpenAPI Documentation"""
 
 
+class ValueTypeHandler(ABC):
+    @abstractmethod
+    def normalize(self, value: Any) -> Any:
+        """Normalizes a value of the given type into another type."""
+
+
+class CommonBuiltInTypesHandler(ValueTypeHandler):
+    def normalize(self, value: Any) -> Any:
+        if isinstance(value, UUID):
+            return str(value)
+
+        if isinstance(value, Enum):
+            return value.value
+
+        if isinstance(value, time):
+            return value.strftime("%H:%M:%S")
+
+        if isinstance(value, datetime):
+            return value.isoformat()
+
+        if isinstance(value, date):
+            return value.strftime("%Y-%m-%d")
+
+        if isinstance(value, bytes):
+            return base64.urlsafe_b64encode(value).decode("utf8")
+
+        return value
+
+
+TYPES_HANDLERS = [CommonBuiltInTypesHandler()]
+
+
 def normalize_key(key: Any) -> str:
     if isinstance(key, Enum):
         return key.value
@@ -39,24 +79,37 @@ def normalize_dict_factory(items: List[Tuple[Any, Any]]) -> Any:
             data["$ref"] = value
             continue
 
-        if isinstance(value, Enum):
-            value = value.value
+        for handler in TYPES_HANDLERS:
+            value = handler.normalize(value)
+
         data[normalize_key(key)] = value
     return data
 
 
+def regular_dict_factory(items: List[Tuple[Any, Any]]) -> Any:
+    data = {}
+    for key, value in items:
+        for handler in TYPES_HANDLERS:
+            value = handler.normalize(value)
+
+        data[key] = value
+    return data
+
+
 # replicates the asdict method from dataclasses module, to support
 # bypassing "asdict" on child properties when they implement a `to_obj`
 # method: some entities require a specific shape when represented
 def _asdict_inner(obj, dict_factory):
     if hasattr(obj, "to_obj"):
         return obj.to_obj()
-    if is_dataclass(obj):
+    if isinstance(obj, OpenAPIElement):
         result = []
         for f in fields(obj):
             value = _asdict_inner(getattr(obj, f.name), dict_factory)
             result.append((f.name, value))
         return dict_factory(result)
+    if is_dataclass(obj):
+        return asdict(obj, dict_factory=regular_dict_factory)
     elif isinstance(obj, (list, tuple)):
         return type(obj)(_asdict_inner(v, dict_factory) for v in obj)
     elif isinstance(obj, dict):
@@ -71,7 +124,9 @@ def _asdict_inner(obj, dict_factory):
 def normalize_dict(obj):
     if hasattr(obj, "to_obj"):
         return obj.to_obj()
-    return _asdict_inner(obj, dict_factory=normalize_dict_factory)
+    if isinstance(obj, OpenAPIElement):
+        return _asdict_inner(obj, dict_factory=normalize_dict_factory)
+    return asdict(obj, dict_factory=regular_dict_factory)
 
 
 class Serializer:
